@@ -2,7 +2,7 @@ package Hades::Realm::Mouse;
 use strict;
 use warnings;
 use base qw/Hades::Realm::OO/;
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
@@ -127,7 +127,7 @@ Hades::Realm::Mouse - Hades realm for Mouse
 
 =head1 VERSION
 
-Version 0.01
+Version 0.08
 
 =cut
 
@@ -250,20 +250,12 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-=over 4
+=over 2
 
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Hades-Realm-Mouse>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Hades-Realm-Mouse>
-
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Hades-Realm-Mouse>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/Hades-Realm-Mouse>
